@@ -541,6 +541,8 @@ OC.L10N.register(
     "Save" : "Guardar",
     "No results" : "Nun hai nengún resultáu",
     "Done" : "Fecho",
+    "Raise hand" : "Alzar la mano",
+    "Lower hand" : "Baxar la mano",
     "This conversation is read-only" : "Esta conversación ye namás de llectura",
     "{nickName} raised their hand." : "«{nickName}» alzo la mano",
     "A participant raised their hand." : "Un participante alzó la mano.",
@@ -549,6 +551,7 @@ OC.L10N.register(
     "Connecting …" : "Conectando…",
     "Calling …" : "Llamando…",
     "Copy link" : "Copiar l'enllaz",
+    "None" : "Nada",
     "Error while accessing camera" : "Hebo un error mentanto s'accedía a la cámara",
     "You are not allowed to enable video" : "Nun tienes permisu p'activar el videu",
     "No video. Click to select device" : "Nun hai videu. Calca pa seleicionar un preséu",
@@ -643,6 +646,7 @@ OC.L10N.register(
     "Decline invitation" : "Refugar la invitación",
     "Accept invitation" : "Aceptar la invitación",
     "No pending invitations" : "Nun hai nenguna invitación pendiente",
+    "Home" : "Aniciu",
     "Unread" : "Ensin lleer",
     "No matches found" : "Nun s'atopó nenguna coincidencia",
     "No conversations found" : "Nun s'atopó nenguna conversación",
@@ -666,7 +670,6 @@ OC.L10N.register(
     "Groups and teams" : "Grupos y equipos",
     "Other sources" : "Otros oríxenes",
     "You are currently waiting in the lobby" : "Tas na sala d'espera",
-    "None" : "Nada",
     "No microphone available" : "Nun hai nengún micrófonu disponible",
     "No camera available" : "Nun hai nenguna cámara disponible",
     "Devices" : "Preseos",
@@ -676,9 +679,7 @@ OC.L10N.register(
     "Access to microphone was denied" : "Negóse l'accesu al micrófonu",
     "Error while accessing microphone" : "Hebo un error mentanto s'accedía al micrófonu",
     "Access to camera is only possible with HTTPS" : "L'accesu a la cámara namás ye posible con HTTPS",
-    "Media settings" : "Configuración multimedia",
     "The call is being recorded." : "La llamada ta grabándose",
-    "Normal call" : "Llamada normal",
     "Invalid path selected" : "Seleicionóse un camín inválidu",
     "Blur" : "Emborrinar",
     "Upload" : "Xunir",
@@ -833,10 +834,12 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Atayos del tecláu",
     "Search" : "Buscar",
     "Space bar" : "Barra d'espaciu",
+    "More actions" : "Más aiciones",
     "Start call" : "Aniciar la llamada",
     "End call" : "Finar la llamada",
     "Stop recording" : "Parar la grabación",
     "Send a reaction" : "Unviar una reaición",
+    "Default" : "Por defeutu",
     "_%n participant in call_::_%n participants in call_" : ["%n participante na llamada","%n participantes na llamada"],
     "You are not allowed to enable screensharing" : "Nun tienes permisu p'activar la compartición de pantalla",
     "Screensharing options" : "Opciones de la compartición de pantalla",
@@ -853,8 +856,6 @@ OC.L10N.register(
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete.",
     "Show your screen" : "Amosar la to pantalla",
     "Stop screensharing" : "Dexar de compartir la pantalla",
-    "Raise hand" : "Alzar la mano",
-    "Lower hand" : "Baxar la mano",
     "Start recording" : "Aniciar la grabación",
     "Keep" : "Caltener",
     "Open dialpad" : "Abrir el tecláu numbéricu",
@@ -939,7 +940,6 @@ OC.L10N.register(
     "Please reload the page." : "Volvi cargar la páxina.",
     "Do not disturb" : "Nun molestar",
     "Away" : "Ausente",
-    "Default" : "Por defeutu",
     "Microphone {number}" : "Micrófonu {number}",
     "Camera {number}" : "Cámara {number}",
     "Access to microphone & camera was denied" : "Negóse l'accesu al micrófonu y a la cámara",
@@ -958,6 +958,8 @@ OC.L10N.register(
     "You were invited to a conversation." : "Convidáronte a una conversación.",
     "{user} invited you to a private conversation" : "{user} convidóte a una conversación privada",
     "Copy conversation link" : "Copiar l'enllaz de la conversación",
+    "Media settings" : "Configuración multimedia",
+    "Normal call" : "Llamada normal",
     "Close" : "Zarrar",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada."
 },
