@@ -557,6 +557,7 @@ OC.L10N.register(
     "Only users of the following groups can enable SIP in conversations they moderate" : "Μόνο οι χρήστες των ακόλουθων ομάδων μπορούν να ενεργοποιήσουν το SIP σε συνομιλίες που εποπτεύουν.",
     "Phone number (Country)" : "Αριθμός τηλεφώνου (Χώρα)",
     "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Αυτές οι πληροφορίες αποστέλλονται σε email πρόσκλησης καθώς και παρουσιάζονται στην πλευρική γραμμή σε όλους τους συμμετέχοντες.",
+    "Error code" : "Σφάλμα κωδικού",
     "High-performance backend URL" : "Διεύθυνση URL backend υψηλής απόδοσης",
     "STUN server URL" : "URL διακομιστή STUN",
     "STUN servers" : "Διακομιστές STUN",
@@ -589,6 +590,13 @@ OC.L10N.register(
     "Search participants" : "Αναζήτηση συμμετεχόντων",
     "No results" : "Κανένα αποτέλεσμα",
     "Done" : "Ολοκληρώθηκε",
+    "Raise hand" : "Σηκώστε το χέρι",
+    "Raise hand (R)" : "Σηκώστε το χέρι (R)",
+    "Lower hand" : "Κατεβάστε το χέρι",
+    "Exit full screen (F)" : "Έξοδος από πλήρη οθόνη (F)",
+    "Full screen (F)" : "Πλήρης οθόνη (F)",
+    "Speaker view" : "Προβολή ομιλητή",
+    "Grid view" : "Προβολή πλέγματος",
     "This conversation is read-only" : "Αυτή η συνομιλία είναι μόνο για ανάγνωση",
     "{nickName} raised their hand." : "Ο {nickName} σήκωσε το χέρι του.",
     "A participant raised their hand." : "Ένας συμμετέχων σήκωσε το χέρι του.",
@@ -604,6 +612,7 @@ OC.L10N.register(
     "Copy link" : "Αντιγραφή συνδέσμου",
     "Mute audio" : "Σίγαση ήχου",
     "Unmute audio" : "Ενεργοποίηση ήχου",
+    "None" : "Κανένα",
     "Access to camera was denied" : "Δεν επιτρέπεται η πρόσβαση στην κάμερα",
     "Error while accessing camera: It is likely in use by another program" : "Σφάλμα κατά την πρόσβαση στην κάμερα: Είναι πιθανό να χρησιμοποιείται από άλλο πρόγραμμα",
     "Error while accessing camera" : "Σφάλμα κατά την πρόσβαση στην κάμερα",
@@ -643,7 +652,6 @@ OC.L10N.register(
     "Meeting" : "Συνάντηση",
     "Conversation settings" : "Ρυθμίσεις συνομιλίας",
     "Personal" : "Προσωπικός",
-    "Always show the device preview screen before joining a call in this conversation." : "Να εμφανίζεται πάντα η οθόνη προεπισκόπησης της συσκευής πριν συμμετάσχετε σε μια κλήση σε αυτήν τη συνομιλία.",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Επικίνδυνη ζώνη",
     "Do you really want to delete \"{displayName}\"?" : "Θέλετε σίγουρα να διαγράψετε το  \"{displayName}\"?",
@@ -701,6 +709,7 @@ OC.L10N.register(
     "Add to favorites" : "Προσθήκη στα αγαπημένα ",
     "You need to promote a new moderator before you can leave the conversation." : "Πρέπει να προάγεται νέο συντονιστή πρίν αποχωρήσετε από την συνομιλία.",
     "Conversation actions" : "Δράσεις συνομιλιών",
+    "Home" : "Σπίτι",
     "Unread" : "Μη αναγνωσμένο",
     "No matches found" : "Δεν βρέθηκαν αντιστοιχίες",
     "An error occurred while performing the search" : "Παρουσιάστηκε σφάλμα κατά την αναζήτηση",
@@ -715,19 +724,24 @@ OC.L10N.register(
     "Users and groups" : "Χρήστες και ομάδες",
     "Other sources" : "Άλλες πηγές",
     "You are currently waiting in the lobby" : "Βρίσκεστε στην αναμονή",
-    "None" : "Κανένα",
     "Select microphone" : "Επιλογή μικροφώνου",
     "No microphone available" : "Δεν βρέθηκε μικρόφωνο",
     "Select camera" : "Επιλογή κάμερας",
     "No camera available" : "Δεν υπάρχει διαθέσιμη κάμερα",
+    "Test" : "Δοκιμή",
     "Devices" : "Συσκευές",
     "No audio" : "Χωρίς ήχο",
     "No camera" : "Χωρίς κάμερα",
+    "Calls are not supported in your browser" : "Οι κλήσεις δεν υποστηρίζονται στον περιηγητή σας.",
+    "Access to microphone is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο είναι εφικτή μόνο μέσω HTTPS.",
+    "Access to microphone was denied" : "Δεν επιτρέπεται η πρόσβαση στο μικρόφωνο",
+    "Error while accessing microphone" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο.",
+    "Access to camera is only possible with HTTPS" : "Η πρόσβαση στην κάμερα είναι εφικτή μόνο μέσω HTTPS.",
     "The call is being recorded." : "Η κλήση καταγράφεται.",
+    "Select a file" : "Επιλογή αρχείου",
     "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
     "Upload" : "Μεταφόρτωση",
     "Files" : "Αρχεία",
-    "Select a file" : "Επιλογή αρχείου",
     "Message read by everyone who shares their reading status" : "Το μήνυμα διαβάστηκε από όλους όσους μοιράζονται την κατάσταση ανάγνωσής τους",
     "Message sent" : "Το μήνυμα στάλθηκε",
     "Deleting message" : "Γίνεται διαγραφή μηνύματος",
@@ -776,9 +790,9 @@ OC.L10N.register(
     "No permission to post messages in this conversation" : "Δεν επιτρέπεται η δημοσίευση μηνυμάτων σε αυτήν τη συνομιλία",
     "Joining conversation …" : "Συμμετοχή σε συνομιλία…",
     "Send message" : "Αποστολή μηνύματος",
+    "File to share" : "Αρχείο για διαμοιρασμό",
     "Add emoji" : "Προσθήκη emoji",
     "Cancel editing" : "Ακύρωση επεξεργασίας",
-    "File to share" : "Αρχείο για διαμοιρασμό",
     "Share from Files" : "Κοινή χρήση από Αρχεία",
     "Share files to the conversation" : "Διαμοιρασμός αρχείων στην συνομιλία",
     "Upload from device" : "Μεταφόρτωση από συσκευή",
@@ -835,24 +849,20 @@ OC.L10N.register(
     "No results found" : "Δεν βρέθηκαν αποτελέσματα",
     "Load more results" : "Φόρτωση περισσοτέρων αποτελεσμάτων",
     "Projects" : "Projects",
+    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "Link to a conversation" : "Σύνδεσμος συνομιλίας",
     "Search conversations or users" : "Αναζήτηση συνομιλιών ή χρηστών",
     "Select conversation" : "Επιλέξτε συνομιλία",
-    "Calls are not supported in your browser" : "Οι κλήσεις δεν υποστηρίζονται στον περιηγητή σας.",
-    "Access to microphone is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο είναι εφικτή μόνο μέσω HTTPS.",
-    "Access to microphone was denied" : "Δεν επιτρέπεται η πρόσβαση στο μικρόφωνο",
-    "Error while accessing microphone" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο.",
-    "Access to camera is only possible with HTTPS" : "Η πρόσβαση στην κάμερα είναι εφικτή μόνο μέσω HTTPS.",
+    "Display name: {name}" : "Εμφανιζόμενο όνομα: {name}",
     "Choose the folder in which attachments should be saved." : "Επιλέξτε το φάκελο στον οποίο θα αποθηκεύονται τα συνημμένα.",
+    "Select location for attachments" : "Επιλέξτε τοποθεσία για τα συνημμένα",
     "Error while setting attachment folder" : "Σφάλμα κατά την ρύθμιση φακέλου συνημμένων",
     "Your privacy setting has been saved" : "Η ρύθμιση απορρήτου σας έχει αποθηκευτεί",
     "Error while setting read status privacy" : "Σφάλμα κατά τον ορισμό απορρήτου κατάστασης ανάγνωσης",
     "Failed to save sounds setting" : "Αποτυχία αποθήκευσης της ρύθμισης ήχων",
     "Sounds setting saved" : "Η ρύθμιση ήχων αποθηκεύτηκε",
     "Error while saving sounds setting" : "Σφάλμα κατά την αποθήκευση της ρύθμισης ήχων",
-    "Choose devices" : "Επιλέξτε συσκευές",
     "Attachments folder" : "Φάκελος συνημμένων",
-    "Select location for attachments" : "Επιλέξτε τοποθεσία για τα συνημμένα",
     "Appearance" : "Εμφάνιση",
     "Privacy" : "Ιδιωτικότητα",
     "Share my read-status and show the read-status of others" : "Μοίρασε την κατάσταση ανάγνωσής μου και δείξε την κατάσταση ανάγνωσης των άλλων",
@@ -872,12 +882,12 @@ OC.L10N.register(
     "Space bar" : "Space",
     "Push to talk or push to mute" : "Πιέστε για να μιλήσετε ή πιέστε για σίγαση",
     "Raise or lower hand" : "Σηκώστε ή κατεβάστε το χέρι",
+    "More actions" : "Περισσότερες ενέργειες",
     "Start call" : "Έναρξη κλήσης",
     "End call" : "Τερματισμός κλήσης",
     "You will be able to join the call only after a moderator starts it." : "Μπορείτε να συμμετάσχετε στην κλήση μόνο μετά την εκκίνηση από τον συντονιστή.",
     "Recording" : "Καταγραφή",
-    "Disable background blur" : "Απενεργοποίηση θολώματος φόντου",
-    "Blur background" : "Θόλωμα φόντου",
+    "Default" : "Προεπιλεγμένο",
     "You are not allowed to enable screensharing" : "Δεν επιτρέπεται να ενεργοποιήσετε τον διαμοιρασμό οθόνης",
     "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
     "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
@@ -888,6 +898,7 @@ OC.L10N.register(
     "Bad sent audio and screen quality." : "Κακή ποιότητα ήχου και διαμοιρασμού οθόνης.",
     "Bad sent audio and video quality." : "Κακή ποιότητα ήχου και βίντεο.",
     "Bad sent audio quality." : "Κακή ποιότητα ήχου.",
+    "Disable background blur" : "Απενεργοποίηση θολώματος φόντου",
     "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να δουν την οθόνη σας.",
     "Your internet connection or computer are busy and other participants might be unable to see you." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας δουν.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να σας δουν. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το βίντεό σας ενώ κάνετε κοινή χρήση οθόνης.",
@@ -903,13 +914,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
     "Show your screen" : "Εμφάνιση της οθόνης σας",
     "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
-    "Exit full screen (F)" : "Έξοδος από πλήρη οθόνη (F)",
-    "Full screen (F)" : "Πλήρης οθόνη (F)",
-    "Speaker view" : "Προβολή ομιλητή",
-    "Grid view" : "Προβολή πλέγματος",
-    "Raise hand" : "Σηκώστε το χέρι",
-    "Raise hand (R)" : "Σηκώστε το χέρι (R)",
-    "Lower hand" : "Κατεβάστε το χέρι",
     "Mute others" : "Σίγαση των άλλων",
     "Start recording" : "Έναρξη εγγραφής",
     "Select a region" : "Επιλογή περιοχής",
@@ -921,7 +925,6 @@ OC.L10N.register(
     "Duplicate session" : "Αντιγραφή συνεδρίας",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Συμμετείχατε στη συνομιλία σε άλλο παράθυρο ή συσκευή. Αυτήν τη στιγμή δεν υποστηρίζεται από το Nextcloud Talk, επομένως αυτή η συνεδρία τερματίστηκε.",
     "Join a conversation or start a new one" : "Συμμετέχετε σε συνομιλία ή ξεκινήστε μια νέα",
-    "Display name: {name}" : "Εμφανιζόμενο όνομα: {name}",
     "Nextcloud URL" : "Διεύθυνση URL του Nextcloud",
     "Nextcloud user" : "Χρήστης του Nextcloud",
     "User password" : "Συνθηματικό χρήστη",
@@ -974,7 +977,6 @@ OC.L10N.register(
     "Show all files" : "Εμφάνιση όλων των αρχείων",
     "Group" : "Ομάδα",
     "You: {lastMessage}" : "Εσείς: {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Προσπαθείτε να συμμετάσχετε σε μια συνομιλία ενώ έχετε ενεργή συνεδρία σε άλλο παράθυρο ή συσκευή. Αυτή τη στιγμή δεν υποστηρίζεται αυτό από το Nextcloud Talk. Τι θέλετε να κάνετε;",
     "Leave this page" : "Αποχώρηση από την σελίδα",
     "Join here" : "Συμμετέχετε εδώ",
@@ -1000,7 +1002,6 @@ OC.L10N.register(
     "Please reload the page." : "Παρακαλούμε φορτώστε ξανά τη σελίδα.",
     "Do not disturb" : "Μην ενοχλείτε",
     "Away" : "Λείπω",
-    "Default" : "Προεπιλεγμένο",
     "Microphone {number}" : "Μικρόφωνο {number}",
     "Camera {number}" : "Κάμερα {number}",
     "Speaker {number}" : "Speaker {number}",
@@ -1027,9 +1028,12 @@ OC.L10N.register(
     "Click the button below to join." : "Πατήστε το κουμπί παρακάτω για συμμετοχή.",
     "Join »%s«" : "Συμμετοχή »%s«",
     "{user} invited you to a private conversation" : "Ο {user} σας προσκάλεσε σε προσωπική συζήτηση",
+    "Always show the device preview screen before joining a call in this conversation." : "Να εμφανίζεται πάντα η οθόνη προεπισκόπησης της συσκευής πριν συμμετάσχετε σε μια κλήση σε αυτήν τη συνομιλία.",
     "Copy conversation link" : "Αντιγραφή συνδέσμου συνομιλίας",
     "Close" : "Κλείσιμο",
+    "Choose devices" : "Επιλέξτε συσκευές",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Το Nextcloud Talk ενημερώθηκε, ανανεώστε τη σελίδα πριν την έναρξη ή συμμετοχή σε μια κλήση.",
+    "Blur background" : "Θόλωμα φόντου",
     "Nextcloud Talk was updated, please reload the page" : "Το Nextcloud Talk ενημερώθηκε, ανανεώστε τη σελίδα",
     "Failed to join the conversation. Try to reload the page." : "Η συμμετοχή στη συνομιλία απέτυχε. Προσπαθήστε να φορτώσετε ξανά τη σελίδα.",
     "Nextcloud is in maintenance mode, please reload the page" : "Το Nextcloud βρίσκεται σε λειτουργία συντήρησης, ανανεώστε τη σελίδα",
