@@ -365,12 +365,15 @@ OC.L10N.register(
     "Save" : "Guardar",
     "No results" : "Sin resultados",
     "Done" : "Terminado",
+    "Exit full screen (F)" : "Salir de pantalla completa (F)",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "You" : "Tú",
@@ -404,13 +407,13 @@ OC.L10N.register(
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
+    "Home" : "Inicio",
     "Unread" : "No leído",
     "Clear filter" : "Limpiar filtro",
     "Users" : " Usuarios",
     "Groups" : "Grupos",
     "Teams" : "Equipos",
     "No search results" : "No hay resultados de búsqueda",
-    "None" : "Ninguno",
     "Select a device" : "Seleccionar un dispositivo",
     "Devices" : "Dispositivos",
     "No audio" : "Sin audio",
@@ -464,6 +467,8 @@ OC.L10N.register(
     "Performance" : "Desempeño",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
+    "More actions" : "Más acciones",
+    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -473,8 +478,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Exit full screen (F)" : "Salir de pantalla completa (F)",
-    "Grid view" : "Vista de cuadrícula",
     "Keep" : "Mantener",
     "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
@@ -498,7 +501,6 @@ OC.L10N.register(
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Do not disturb" : "No molestar",
     "Away" : "Ausente",
-    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
