@@ -618,6 +618,12 @@ OC.L10N.register(
     "Save" : "Spremi",
     "Search participants" : "Pretraži sudionike",
     "No results" : "Nema rezultata",
+    "Raise hand" : "Podigni ruku",
+    "Raise hand (R)" : "Podigni ruku (R)",
+    "Lower hand" : "Spusti ruku",
+    "Lower hand (R)" : "Spusti ruku (R)",
+    "Speaker view" : "Prikaz govornika",
+    "Grid view" : "Prikaz rešetke",
     "This conversation is read-only" : "Ovaj razgovor je samo za čitanje",
     "{nickName} raised their hand." : "{nickName} je podigao ruku.",
     "A participant raised their hand." : "Sudionik je podigao ruku.",
@@ -636,6 +642,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Isključi zvuk (M)",
     "Unmute audio" : "Uključi zvuk",
     "Unmute audio (M)" : "Uključi zvuk (M)",
+    "None" : "Nema",
     "Access to camera was denied" : "Pristup kameri je odbijen",
     "Error while accessing camera" : "Došlo je do pogreške pri pristupanju kameri",
     "You have been muted by a moderator" : "Utišao vas je moderator",
@@ -738,6 +745,7 @@ OC.L10N.register(
     "Add to favorites" : "Dodaj u favorite",
     "You need to promote a new moderator before you can leave the conversation." : "Morate odabrati novog moderatora prije nego što napustite razgovor.",
     "Conversation actions" : "Radnje razgovora",
+    "Home" : "Doma",
     "No matches found" : "Nema pronađenih podudaranja",
     "No conversations found" : "Nije pronađen nijedan razgovor",
     "An error occurred while performing the search" : "Došlo je do pogreške pri pretraživanju",
@@ -754,7 +762,6 @@ OC.L10N.register(
     "The meeting will start soon" : "Sastanak počinje uskoro",
     "This meeting is scheduled for {startTime}" : "Sastanak počinje u {startTime}",
     "You are currently waiting in the lobby" : "Trenutno čekate u predvorju",
-    "None" : "Nema",
     "Select microphone" : "Odaberi mikrofon",
     "No microphone available" : "Nema dostupnih mikrofona",
     "Select camera" : "Odaberi kameru",
@@ -913,11 +920,11 @@ OC.L10N.register(
     "Space bar" : "Razmaknica",
     "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
     "Raise or lower hand" : "Podigni ili spusti ruku",
+    "More actions" : "Dodatne radnje",
     "Start call" : "Uputi poziv",
     "You will be able to join the call only after a moderator starts it." : "Pozivu ćete se moći pridružiti tek nakon što ga moderator pokrene.",
     "Recording" : "Snimanje",
-    "Disable background blur" : "Onemogući zamućenje pozadine",
-    "Blur background" : "Zamuti pozadinu",
+    "Default" : "Zadano",
     "You are not allowed to enable screensharing" : "Nije vam dopušteno omogućiti dijeljenje zaslona",
     "No screensharing" : "Nema dijeljenja zaslona",
     "Screensharing options" : "Mogućnosti dijeljenja zaslona",
@@ -929,6 +936,7 @@ OC.L10N.register(
     "Bad sent audio and screen quality." : "Nekvalitetan audiozapis i prikaz.",
     "Bad sent audio and video quality." : "Nekvalitetan audiozapis i videozapis.",
     "Bad sent audio quality." : "Nekvalitetan audiozapis.",
+    "Disable background blur" : "Onemogući zamućenje pozadine",
     "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa dok dijelite zaslon.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon.",
     "Your internet connection or computer are busy and other participants might be unable to see you." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti.",
@@ -948,12 +956,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Došlo je do pogreške pri pokretanju dijeljenja zaslona.",
     "Show your screen" : "Pokaži svoj zaslon",
     "Stop screensharing" : "Prekini dijeljenje zaslona",
-    "Speaker view" : "Prikaz govornika",
-    "Grid view" : "Prikaz rešetke",
-    "Raise hand" : "Podigni ruku",
-    "Raise hand (R)" : "Podigni ruku (R)",
-    "Lower hand" : "Spusti ruku",
-    "Lower hand (R)" : "Spusti ruku (R)",
     "Mute others" : "Utišaj druge",
     "Select a region" : "Odaberite regiju",
     "Submit" : "Šalji",
@@ -1044,7 +1046,6 @@ OC.L10N.register(
     "Please reload the page." : "Ponovno učitajte stranicu.",
     "Do not disturb" : "Ne ometaj",
     "Away" : "Odsutan",
-    "Default" : "Zadano",
     "Microphone {number}" : "Mikrofon {number}",
     "Camera {number}" : "Kamera {number}",
     "Speaker {number}" : "Zvučnik {number}",
@@ -1076,6 +1077,7 @@ OC.L10N.register(
     "Close" : "Zatvori",
     "Choose devices" : "Odaberi uređaje",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu prije upućivanja ili pridruživanja razgovoru.",
+    "Blur background" : "Zamuti pozadinu",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu",
     "An error happened when trying to share your file" : "Došlo je do pogreške pri pokušaju dijeljenja datoteke",
     "Failed to join the conversation. Try to reload the page." : "Pridruživanje razgovoru nije uspjelo. Pokušajte ponovno učitati stranicu.",
