@@ -684,7 +684,6 @@ OC.L10N.register(
     "Full screen (F)" : "Schermo intero (F)",
     "Speaker view" : "Visualizzazione oratore",
     "Grid view" : "Vista Griglia",
-    "You need to close a dialog to toggle full screen" : "È necessario chiudere una finestra per passare alla modalità a schermo intero",
     "This conversation is read-only" : "Questa conversazione è in sola lettura",
     "{nickName} raised their hand." : "{nickName} ha alzato la mano.",
     "A participant raised their hand." : "Un partecipante ha alzato la mano.",
@@ -835,6 +834,7 @@ OC.L10N.register(
     "Add to favorites" : "Aggiungi ai preferiti",
     "You need to promote a new moderator before you can leave the conversation." : "Devi promuovere un nuovo moderatore prima di poter abbandonare la conversazione. ",
     "Conversation actions" : "Azioni delle conversazioni",
+    "Home" : "Home",
     "Unread" : "Da leggere",
     "No matches found" : "Nessuna corrispondenza trovata",
     "No conversations found" : "Nessuna conversazione trovata",
@@ -845,6 +845,7 @@ OC.L10N.register(
     "Talk settings" : "Impostazioni di Talk",
     "Users" : "Utenti",
     "Groups" : "Gruppi",
+    "Teams" : "Team",
     "Open conversations" : "Apri conversazioni",
     "No search results" : "Nessun risultato di ricerca",
     "Users and groups" : "Utenti e gruppi",
@@ -1223,6 +1224,7 @@ OC.L10N.register(
     "Choose devices" : "Scegli i dispositivi",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk è stato aggiornato, devi ricaricare la pagina prima di poter iniziare o partecipare a una chiamata.",
     "Blur background" : "Sfocatura dello sfondo",
+    "You need to close a dialog to toggle full screen" : "È necessario chiudere una finestra per passare alla modalità a schermo intero",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk è stato aggiornato, ricarica la pagina",
     "An error happened when trying to share your file" : "Si è verificato un errore durante il tentativo di condividere il tuo file",
     "Failed to join the conversation. Try to reload the page." : "Partecipazione alla conversazione non riuscita. Prova a ricaricare la pagina.",
