@@ -3,14 +3,14 @@ OC.L10N.register(
     {
     "a conversation" : "saruna",
     "(Duration %s)" : "(Ilgums %s)",
-    "You attended a call with {user1}" : "Jūs piedalījāties sarunā ar {user1}",
+    "You attended a call with {user1}" : "Tu piedalījies zvanā ar {user1}",
     "_%n guest_::_%n guests_" : ["%n viesi","%n viesi","%n viesi"],
-    "You attended a call with {user1} and {user2}" : "Jūs piedalījāties sarunā ar {user1} un {user2}",
-    "You attended a call with {user1}, {user2} and {user3}" : "Jūs piedalījāties sarunā ar {user1}, {user2} un {user3}",
-    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Jūs piedalījāties sarunā ar {user1}, {user2}, {user3} un {user4}",
-    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Jūs piedalījāties sarunā ar {user1}, {user2}, {user3}, {user4} un {user5}",
+    "You attended a call with {user1} and {user2}" : "Tu piedalījies zvanā ar {user1} un {user2}",
+    "You attended a call with {user1}, {user2} and {user3}" : "Tu piedalījies zvanā ar {user1}, {user2} un {user3}",
+    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tu piedalījies zvanā ar {user1}, {user2}, {user3} un {user4}",
+    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tu piedalījies zvanā ar {user1}, {user2}, {user3}, {user4} un {user5}",
     "_%n other_::_%n others_" : ["%n other","%n cits","%n citi"],
-    "{actor} invited you to {call}" : "{actor} uzaicināja jūs uz {call}",
+    "{actor} invited you to {call}" : "{actor} uzaicināja Tevi {call}",
     "Talk" : "Runāt",
     "Guest" : "Viesis",
     "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Viens pret vienu sarunas tagad ir pastāvīgas, un tās vairs nevar nejauši pārveidot par kopu sarunām. Kā arī, kad viens no dalībniekiem pamet sarunu, tā vairs netiek automātiski izdzēsta. Tikai ja abi dalībnieki izies, saruna tiks izdzēsta no servera",
@@ -20,32 +20,32 @@ OC.L10N.register(
     "{actor} created the conversation" : "{actor} izveidoja sarunu",
     "You created the conversation" : "Tu izveidoji sarunu",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
-    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pārdēvējāt sarunu no \"%1$s\" uz \"%2$s\"",
+    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Tu pārdēvēji sarunu no \"%1$s\" uz \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Pārvaldītājs pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
     "You removed the description" : "Tu noņēmi aprakstu",
-    "You started a call" : "Jūs sākāt zvanu",
+    "You started a call" : "Tu uzsāki zvanu",
     "{actor} started a call" : "{actor} sācis zvanu",
     "{actor} joined the call" : "{actor} pievienojies zvanam",
-    "You joined the call" : "Jūs pievienojaties zvanam",
+    "You joined the call" : "Tu pievienojies zvanam",
     "{actor} left the call" : "{actor} pameta zvanu",
     "You left the call" : "Tu pameti zvanu",
     "{actor} unlocked the conversation" : "{actor} atslēdz sarunu",
-    "You unlocked the conversation" : "Jūs atslēdzāt sarunu",
+    "You unlocked the conversation" : "Tu atslēdzi sarunu",
     "{actor} locked the conversation" : "{actor} bloķē sarunu",
-    "You locked the conversation" : "Jūs bloķējāt sarunu",
+    "You locked the conversation" : "Tu aizslēdzi sarunu",
     "{actor} allowed guests" : "{actor} atļauj viesus",
-    "You allowed guests" : "Jūs atļaujat viesus",
+    "You allowed guests" : "Tu atļāvi viesus",
     "{actor} disallowed guests" : "{actor} nepieļāva viesus",
-    "You disallowed guests" : "Jūs nepieļāvāt viesus",
+    "You disallowed guests" : "Tu neatļāvi viesus",
     "{actor} set a password" : "{actor} iestatīja paroli",
-    "You set a password" : "Jūs iestatījāt paroli",
+    "You set a password" : "Tu iestatīji paroli",
     "{actor} removed the password" : "{actor} noņēma paroli",
     "You removed the password" : "Tu noņēmi paroli",
     "{actor} added {user}" : "{actor} pievienoja {user}",
-    "You joined the conversation" : "Jūs pievienojaties sarunai",
+    "You joined the conversation" : "Tu pievienojies sarunai",
     "{actor} joined the conversation" : "{actor} pievienojās sarunai",
     "You added {user}" : "Tu pievienoji {user}",
-    "{actor} added you" : "{actor} jūs pievienoja",
+    "{actor} added you" : "{actor} pievienoja Tevi",
     "You left the conversation" : "Tu pameti sarunu",
     "{actor} left the conversation" : "{actor} pameta sarunu",
     "{actor} removed {user}" : "{actor} noņēma {user}",
@@ -54,14 +54,14 @@ OC.L10N.register(
     "You removed {federated_user}" : "Tu noņēmi {federated_user}",
     "You added {phone}" : "Tu pievienoji {phone}",
     "You removed {phone}" : "Tu noņēmi {phone}",
-    "{actor} promoted {user} to moderator" : "{actor} paaugstināja {user} par regulētāju",
-    "You promoted {user} to moderator" : "Jūs paaugstinājāt {user} par regulētāju",
-    "{actor} promoted you to moderator" : "{actor} paaugstināja jūs par regulētāju",
-    "{actor} demoted {user} from moderator" : "{actor} pazemināts {user} no regulētāja",
-    "You demoted {user} from moderator" : "Jūs pazeminājāt {user} no regulētāja",
-    "{actor} demoted you from moderator" : "{actor} pazemināja jūs no regulētāja",
+    "{actor} promoted {user} to moderator" : "{actor} iecēla {user} par satura pārraudzītāju",
+    "You promoted {user} to moderator" : "Tu iecēli {user} par satura pārraudzītāju",
+    "{actor} promoted you to moderator" : "{actor} iecēla Tevi par satura pārraudzītāju",
+    "{actor} demoted {user} from moderator" : "{actor} pazemināja {user} no satura pārraudzītāja",
+    "You demoted {user} from moderator" : "Tu pazemināji {user} no satura pārraudzītāja",
+    "{actor} demoted you from moderator" : "{actor} pazemināja Tevi no satura pārraudzītāja",
     "{actor} shared a file which is no longer available" : "{actor} kopīgoja datni, kas vairs nav pieejama",
-    "You shared a file which is no longer available" : "Jūs kopīgojāt datni, kas vairs nav pieejama",
+    "You shared a file which is no longer available" : "Tu kopīgoji datni, kas vairs nav pieejama",
     "Message deleted by author" : "Ziņojumu izdzēsa autors",
     "Administration" : "Pārvaldīšana",
     "System" : "Sistēma",
@@ -91,10 +91,10 @@ OC.L10N.register(
     "A deleted user sent a message in conversation {call}" : "Izdzēsts lietotājs nosūtīja ziņojumu sarunā {call}",
     "A guest sent a message in conversation {call}" : "Viesis nosūtījis ziņojumu sarunā {call}",
     "{user} mentioned you in a private conversation" : "{user} tevi pieminēja privātā sarunā",
-    "{user} mentioned you in conversation {call}" : "{user} pieminēja jūs sarunā {call}",
+    "{user} mentioned you in conversation {call}" : "{user} pieminēja Tevi sarunā {call}",
     "A deleted user mentioned you in conversation {call}" : "Izdzēsts lietotājs pieminēja Tevi sarunā {call}",
-    "A guest mentioned you in conversation {call}" : "Kāds viesis jūs pieminēja sarunā {call}",
-    "{user} invited you to a group conversation: {call}" : "{user} uzaicināja jūs uz grupas sarunu: {call}",
+    "A guest mentioned you in conversation {call}" : "Viesis pieminēja Tevi sarunā {call}",
+    "{user} invited you to a group conversation: {call}" : "{user} uzaicināja Tevi uz grupas sarunu: {call}",
     "Join call" : "Pievienoties zvanam",
     "{user} would like to talk with you" : "{user} vēlas runāt ar Tevi",
     "A group call has started in {call}" : "Grupas zvans ir sācies {call}",
@@ -341,6 +341,7 @@ OC.L10N.register(
     "Zambia" : "Zambija",
     "Zimbabwe" : "Zimbabve",
     "Federation" : "Federācija",
+    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nav uzstādīts, tas var novest pie veiktspējas sarežģījumiem, kad izmanto darbvirsmas klientus.",
     "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
     "Conversation not found" : "Saruna nav atrasta",
     "Chat, video & audio-conferencing using WebRTC" : "Video un audio konferences, izmantojot WebRTC",
@@ -362,7 +363,7 @@ OC.L10N.register(
     "Name" : "Nosaukums",
     "Beta" : "Beta",
     "Permissions" : "Atļaujas",
-    "General settings" : "Vispārīgie iestatījumi",
+    "General settings" : "Vispārīgi iestatījumi",
     "Enable encryption" : "Ieslēgt šifrēšanu",
     "Pending" : "Gaida",
     "Error" : "Kļūda",
@@ -406,7 +407,7 @@ OC.L10N.register(
     "None" : "Nav",
     "Disable video" : "Atspējot video",
     "Enable video" : "Iespējot video",
-    "You" : "Jūs",
+    "You" : "Tu",
     "Show screen" : "Rādīt ekrānu",
     "Collapse" : "Sakļaut",
     "Favorite" : "Izlasē",
@@ -437,7 +438,8 @@ OC.L10N.register(
     "Log in" : "Pieteikties",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
-    "You need to promote a new moderator before you can leave the conversation." : "Pirms sarunas atstāšanas ir jāieceļ jauns regulētājs.",
+    "You need to promote a new moderator before you can leave the conversation." : "Ir nepieciešams iecelt jaunu satura pārraudzītāju, lai Tu varētu pamest sarunu.",
+    "Home" : "Sākums",
     "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
     "Clear filter" : "Notīrīt atlasi",
     "Users" : "Lietotāji",
@@ -466,11 +468,11 @@ OC.L10N.register(
     "New file" : "Jauna datne",
     "Send" : "Sūtīt",
     "Settings" : "Iestatījumi",
-    "moderator" : "moderators",
+    "moderator" : "satura pārraudzītājs",
     "guest" : "viesis",
     "Remove participant" : "Noņemt dalībnieku",
-    "Demote from moderator" : "Pazemināt no regulētāja",
-    "Promote to moderator" : "Paaugstināt par regulētāju",
+    "Demote from moderator" : "Pazemināt no satura pārraudzītāja",
+    "Promote to moderator" : "Iecelt par satura pārraudzītāju",
     "Remove" : "Noņemt",
     "Add users or groups" : "Add users or groups",
     "Add users or teams" : "Pievienot lietotājus vai komandas",
@@ -528,7 +530,7 @@ OC.L10N.register(
     "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
-    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
+    "Please reload the page." : "Lūgums pārlādēt lapu",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, lūgums palaist savu pārlūku no jauna, jo ir skaņas un video atteice",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
     "Please move your setup to HTTPS" : "Lūdzu, pārvietojiet iestatījumu uz HTTPS",
@@ -536,6 +538,7 @@ OC.L10N.register(
     "WebRTC is not supported in your browser" : "Pārlūkā netiek atbalstīts WebRTC",
     "Please use a different browser like Firefox or Chrome" : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome",
     "Error while accessing microphone & camera" : "Kļūda, piekļūstot mikrofonam un kamerai",
+    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Mēs esam noteikuši vairākus nederīgus paroles mēģinājumus no šīs IP adreses, tādējādi nākamā pieteikšanās ir ierobežota līdz 30 sekundēm.",
     "The password is wrong. Try again." : "Nepareiza parole. Jāmēģina vēlreiz.",
     "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
     "Android app" : "Android lietotne",
@@ -545,11 +548,11 @@ OC.L10N.register(
     "Tasks" : "Uzdevumi",
     "Notes" : "Piezīmes",
     "Reports" : "Atskaites",
-    "%s invited you to a conversation." : "%s uzaicināja jūs uz sarunu.",
-    "You were invited to a conversation." : "Jūs uzaicinājāt uz sarunu.",
+    "%s invited you to a conversation." : "%s uzaicināja Tevi uz sarunu.",
+    "You were invited to a conversation." : "Tu uzaicinājāt uz sarunu.",
     "Click the button below to join." : "Jāklikšķina uz zemāk esošās pogas, lai pievienotos.",
     "Join »%s«" : "Pievienoties »%s«",
-    "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
+    "{user} invited you to a private conversation" : "{user} uzaicināja Tevi uz privātu sarunu",
     "Close" : "Aizvērt"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
