@@ -609,6 +609,12 @@ OC.L10N.register(
     "Save" : "Sarva",
     "Search participants" : "Chirca partetzipantes",
     "No results" : "Perunu resurtadu",
+    "Raise hand" : "Àrtzia sa manu ",
+    "Raise hand (R)" : "Àrtzia sa manu (R)",
+    "Lower hand" : "Bàscia sa manu ",
+    "Lower hand (R)" : "Bàscia sa manu (R)",
+    "Speaker view" : "Bista de sa persone chi faeddat",
+    "Grid view" : "Bisione grìllia",
     "This conversation is read-only" : "Custa resonada est de letura sola",
     "{nickName} raised their hand." : "{nickName} ant artziadu sa manu",
     "A participant raised their hand." : "Una persona at artziadu sa manu",
@@ -627,6 +633,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Istuda s'àudiu (M)",
     "Unmute audio" : "Allue s'àudiu ",
     "Unmute audio (M)" : "Allue s'àudiu (M)",
+    "None" : "Perunu",
     "Access to camera was denied" : "S'atzessu a sa càmera est istadu negadu",
     "Error while accessing camera" : "Errore in s'atzessu a sa càmera",
     "You have been muted by a moderator" : "Una persona chi moderat ti nd'at tiradu s'àudiu",
@@ -725,6 +732,7 @@ OC.L10N.register(
     "Add to favorites" : "Agiunghe a preferidos",
     "You need to promote a new moderator before you can leave the conversation." : "Depes promòvere un'àtera persona chi moderet antis de lassare sa resonada.",
     "Conversation actions" : "Atziones de is resonadas",
+    "Home" : "Pàgina printzipale",
     "Unread" : "De lèghere",
     "No matches found" : "Peruna currispondèntzia agatada",
     "No conversations found" : "Peruna resonada agatada",
@@ -743,7 +751,6 @@ OC.L10N.register(
     "Other sources" : "Àteras fontes",
     "New group conversation" : "Resonada de grupu noa",
     "You are currently waiting in the lobby" : "Immoe ses abetende in s'intrada",
-    "None" : "Perunu",
     "Select microphone" : "Seletziona su micròfonu",
     "No microphone available" : "Perunu micròfonu a disponimentu",
     "Select camera" : "Seletziona sa fotocàmera",
@@ -757,7 +764,6 @@ OC.L10N.register(
     "Access to microphone was denied" : "S'atzessu a su micròfonu est istadu negadu",
     "Error while accessing microphone" : "Errore in s'atzessu a su micròfonu",
     "Access to camera is only possible with HTTPS" : "S'atzessu a sa càmera si podet fàghere isceti cun HTTPS",
-    "Media settings" : "Cunfiguratzione de is elementos multimediales",
     "Invalid path selected" : "Percursu seletzionadu non bàlidu",
     "Upload" : "Càrriga",
     "Files" : "Archìvios",
@@ -899,9 +905,11 @@ OC.L10N.register(
     "Space bar" : "Istanca de logu",
     "Push to talk or push to mute" : "Ispinghe pro faeddare o ispinghe pro tirare s'àudio",
     "Raise or lower hand" : "Àrtzia o bàscia sa manu",
+    "More actions" : "Àteras atziones",
     "Start call" : "Cumintza mutida",
     "You will be able to join the call only after a moderator starts it." : "As a pòdere intrare in una mutida isceti a pustis chi una persone chi moderat dda cumintzet.",
     "Recording" : "Registratzione",
+    "Default" : "Predefinidu",
     "You are not allowed to enable screensharing" : "Non tenes su permissu de ativare sa cumpartzidura de s'ischermu",
     "No screensharing" : "Peruna cumpartzidura de ischermu",
     "Screensharing options" : "Sèberos de sa cumpartzidura de s'ischermu",
@@ -928,12 +936,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "B'at àpidu un'errore incarrerende sa cumpartzidura de s'ischermu.",
     "Show your screen" : "Mustra s'ischermu tuo",
     "Stop screensharing" : "Firma sa cumpartzidura de s'ischermu",
-    "Speaker view" : "Bista de sa persone chi faeddat",
-    "Grid view" : "Bisione grìllia",
-    "Raise hand" : "Àrtzia sa manu ",
-    "Raise hand (R)" : "Àrtzia sa manu (R)",
-    "Lower hand" : "Bàscia sa manu ",
-    "Lower hand (R)" : "Bàscia sa manu (R)",
     "Mute others" : "Tira s'àudio a àtere",
     "Keep" : "Mantene",
     "Select a region" : "Seletziona una regione",
@@ -1025,7 +1027,6 @@ OC.L10N.register(
     "Please reload the page." : "Torra a carrigare sa pàgina.",
     "Do not disturb" : "No istorbes",
     "Away" : "Foras",
-    "Default" : "Predefinidu",
     "Microphone {number}" : "Micròfonu {number}",
     "Camera {number}" : "Fotocàmera {number}",
     "Speaker {number}" : "Altoparlante {number}",
@@ -1053,6 +1054,7 @@ OC.L10N.register(
     "Join »%s«" : "Intra in »%s«",
     "{user} invited you to a private conversation" : "{user} t'at invitadu in una resonada privada",
     "Copy conversation link" : "Còpia su ligòngiu de sa resonada",
+    "Media settings" : "Cunfiguratzione de is elementos multimediales",
     "Close" : "Serra",
     "Choose devices" : "Sèbera dispositivos",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk est istadu agiornadu, depes torrare a carrigare sa pàgina antis de pòdere cumintzare o intrare in una mutida.",
