@@ -330,7 +330,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		]);
 
 		try {
-			$comment = $this->chatManager->addSystemMessage($this->room, $actorType, $actorId, $message, $creationDateTime, true, $referenceId);
+			$comment = $this->chatManager->addSystemMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime, true, $referenceId);
 		} catch (MessageTooLongException $e) {
 			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
 		} catch (\Exception $e) {
@@ -761,9 +761,14 @@ class ChatController extends AEnvironmentAwareOCSController {
 		}
 
 		$currentUser = $this->userManager->get($this->userId);
-		$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $limit, true);
-		$commentsHistory = array_reverse($commentsHistory);
-		$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false);
+		if ($messageId === 0) {
+			// Guest in a fully expired chat, no history, just loading the chat from beginning for now
+			$commentsHistory = $commentsFuture = [];
+		} else {
+			$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $limit, true);
+			$commentsHistory = array_reverse($commentsHistory);
+			$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false);
+		}
 
 		return $this->prepareCommentsAsDataResponse(array_merge($commentsHistory, $commentsFuture));
 	}
@@ -1534,10 +1539,13 @@ class ChatController extends AEnvironmentAwareOCSController {
 		$results = array_merge_recursive($exactMatches, $results);
 
 		$this->autoCompleteManager->registerSorter(Sorter::class);
+		/** @psalm-suppress InvalidArgument */
 		$this->autoCompleteManager->runSorters(['talk_chat_participants'], $results, [
 			'itemType' => 'chat',
 			'itemId' => (string)$this->room->getId(),
 			'search' => $search,
+			'selfUserId' => $this->userId,
+			'selfCloudId' => $this->userId === null ? $this->federationAuthenticator->getCloudId() : null,
 		]);
 
 		$statuses = [];
