@@ -2,67 +2,40 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2017 Joachim Bauch <bauch@struktur.de>
- *
- * @author Joachim Bauch <bauch@struktur.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Signaling;
 
 use GuzzleHttp\Exception\ConnectException;
 use GuzzleHttp\Exception\ServerException;
+use OC\Http\Client\Response;
 use OCA\Talk\Config;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCP\AppFramework\Services\IAppConfig;
 use OCP\Http\Client\IClientService;
+use OCP\Http\Client\IResponse;
 use OCP\IURLGenerator;
 use OCP\Security\ISecureRandom;
 use Psr\Log\LoggerInterface;
 
 class BackendNotifier {
-	private Config $config;
-	private LoggerInterface $logger;
-	private IClientService $clientService;
-	private ISecureRandom $secureRandom;
-	private Manager $signalingManager;
-	private ParticipantService $participantService;
-	private IURLGenerator $urlGenerator;
 
 	public function __construct(
-		Config $config,
-		LoggerInterface $logger,
-		IClientService $clientService,
-		ISecureRandom $secureRandom,
-		Manager $signalingManager,
-		ParticipantService $participantService,
-		IURLGenerator $urlGenerator,
+		private Config $config,
+		private IAppConfig $appConfig,
+		private LoggerInterface $logger,
+		private IClientService $clientService,
+		private ISecureRandom $secureRandom,
+		private Manager $signalingManager,
+		private ParticipantService $participantService,
+		private IURLGenerator $urlGenerator,
 	) {
-		$this->config = $config;
-		$this->logger = $logger;
-		$this->clientService = $clientService;
-		$this->secureRandom = $secureRandom;
-		$this->signalingManager = $signalingManager;
-		$this->participantService = $participantService;
-		$this->urlGenerator = $urlGenerator;
 	}
 
 	/**
@@ -72,12 +45,13 @@ class BackendNotifier {
 	 * @param string $url
 	 * @param array $params
 	 * @param int $retries
+	 * @return ?IResponse
 	 * @throws \Exception
 	 */
-	protected function doRequest(string $url, array $params, int $retries = 3): void {
+	protected function doRequest(string $url, array $params, int $retries = 3): ?IResponse {
 		if (defined('PHPUNIT_RUN')) {
 			// Don't perform network requests when running tests.
-			return;
+			return null;
 		}
 
 		$client = $this->clientService->newClient();
@@ -87,15 +61,30 @@ class BackendNotifier {
 			if (!$this->signalingManager->isCompatibleSignalingServer($response)) {
 				throw new \RuntimeException('Signaling server needs to be updated to be compatible with this version of Talk');
 			}
-		} catch (ServerException | ConnectException $e) {
+
+			return $response;
+		} catch (ConnectException $e) {
 			if ($retries > 1) {
 				$this->logger->error('Failed to send message to signaling server, ' . $retries . ' retries left!', ['exception' => $e]);
-				$this->doRequest($url, $params, $retries - 1);
-			} else {
-				$this->logger->error('Failed to send message to signaling server, giving up!', ['exception' => $e]);
+				return $this->doRequest($url, $params, $retries - 1);
 			}
+
+			$this->logger->error('Failed to send message to signaling server, giving up!', ['exception' => $e]);
+			throw $e;
+		} catch (ServerException $e) {
+			if ($retries > 1) {
+				$this->logger->error('Failed to send message to signaling server, ' . $retries . ' retries left!', ['exception' => $e]);
+				return $this->doRequest($url, $params, $retries - 1);
+			}
+
+			$this->logger->error('Failed to send message to signaling server, giving up!', ['exception' => $e]);
+			if ($e->hasResponse()) {
+				return new Response($e->getResponse());
+			}
+			throw $e;
 		} catch (\Exception $e) {
 			$this->logger->error('Failed to send message to signaling server', ['exception' => $e]);
+			throw $e;
 		}
 	}
 
@@ -104,11 +93,12 @@ class BackendNotifier {
 	 *
 	 * @param Room $room
 	 * @param array $data
+	 * @return ?IResponse
 	 * @throws \Exception
 	 */
-	private function backendRequest(Room $room, array $data): void {
+	private function backendRequest(Room $room, array $data): ?IResponse {
 		if ($this->config->getSignalingMode() === Config::SIGNALING_INTERNAL) {
-			return;
+			return null;
 		}
 
 		// FIXME some need to go to all HPBs, but that doesn't scale, so bad luck for now :(
@@ -117,9 +107,9 @@ class BackendNotifier {
 
 		$url = '/api/v1/room/' . $room->getToken();
 		$url = $signaling['server'] . $url;
-		if (strpos($url, 'wss://') === 0) {
+		if (str_starts_with($url, 'wss://')) {
 			$url = 'https://' . substr($url, 6);
-		} elseif (strpos($url, 'ws://') === 0) {
+		} elseif (str_starts_with($url, 'ws://')) {
 			$url = 'http://' . substr($url, 5);
 		}
 		$body = json_encode($data);
@@ -143,21 +133,21 @@ class BackendNotifier {
 		if (empty($signaling['verify'])) {
 			$params['verify'] = false;
 		}
-		$this->doRequest($url, $params);
+		return $this->doRequest($url, $params);
 	}
 
 	/**
 	 * The given users are now invited to a room.
 	 *
 	 * @param Room $room
-	 * @param array[] $users
+	 * @param Attendee[] $attendees
 	 * @throws \Exception
 	 */
-	public function roomInvited(Room $room, array $users): void {
+	public function roomInvited(Room $room, array $attendees): void {
 		$userIds = [];
-		foreach ($users as $user) {
-			if ($user['actorType'] === Attendee::ACTOR_USERS) {
-				$userIds[] = $user['actorId'];
+		foreach ($attendees as $attendee) {
+			if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
+				$userIds[] = $attendee->getActorId();
 			}
 		}
 		$start = microtime(true);
@@ -167,14 +157,14 @@ class BackendNotifier {
 				'userids' => $userIds,
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
-				'alluserids' => $this->participantService->getParticipantUserIds($room),
+				'alluserids' => $this->participantService->getParticipantUserIdsAndFederatedUserCloudIds($room),
 				'properties' => $room->getPropertiesForSignaling('', false),
 			],
 		]);
 		$duration = microtime(true) - $start;
 		$this->logger->debug('Now invited to {token}: {users} ({duration})', [
 			'token' => $room->getToken(),
-			'users' => print_r($users, true),
+			'users' => print_r($userIds, true),
 			'duration' => sprintf('%.2f', $duration),
 			'app' => 'spreed-hpb',
 		]);
@@ -184,10 +174,18 @@ class BackendNotifier {
 	 * The given users are no longer invited to a room.
 	 *
 	 * @param Room $room
-	 * @param string[] $userIds
+	 * @param Attendee[] $attendees
 	 * @throws \Exception
 	 */
-	public function roomsDisinvited(Room $room, array $userIds): void {
+	public function roomsDisinvited(Room $room, array $attendees): void {
+		$allUserIds = $this->participantService->getParticipantUserIdsAndFederatedUserCloudIds($room);
+		sort($allUserIds);
+		$userIds = [];
+		foreach ($attendees as $attendee) {
+			if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
+				$userIds[] = $attendee->getActorId();
+			}
+		}
 		$start = microtime(true);
 		$this->backendRequest($room, [
 			'type' => 'disinvite',
@@ -195,7 +193,7 @@ class BackendNotifier {
 				'userids' => $userIds,
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
-				'alluserids' => $this->participantService->getParticipantUserIds($room),
+				'alluserids' => $allUserIds,
 				'properties' => $room->getPropertiesForSignaling('', false),
 			],
 		]);
@@ -216,6 +214,8 @@ class BackendNotifier {
 	 * @throws \Exception
 	 */
 	public function roomSessionsRemoved(Room $room, array $sessionIds): void {
+		$allUserIds = $this->participantService->getParticipantUserIdsAndFederatedUserCloudIds($room);
+		sort($allUserIds);
 		$start = microtime(true);
 		$this->backendRequest($room, [
 			'type' => 'disinvite',
@@ -223,7 +223,7 @@ class BackendNotifier {
 				'sessionids' => $sessionIds,
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
-				'alluserids' => $this->participantService->getParticipantUserIds($room),
+				'alluserids' => $allUserIds,
 				'properties' => $room->getPropertiesForSignaling('', false),
 			],
 		]);
@@ -247,6 +247,9 @@ class BackendNotifier {
 		$this->backendRequest($room, [
 			'type' => 'update',
 			'update' => [
+				// Message not sent for federated users, as they will receive
+				// the message from their federated Nextcloud server once the
+				// property change is propagated.
 				'userids' => $this->participantService->getParticipantUserIds($room),
 				'properties' => $room->getPropertiesForSignaling(''),
 			],
@@ -323,7 +326,9 @@ class BackendNotifier {
 		foreach ($participants as $participant) {
 			$attendee = $participant->getAttendee();
 			if ($attendee->getActorType() !== Attendee::ACTOR_USERS
-				&& $attendee->getActorType() !== Attendee::ACTOR_GUESTS) {
+				&& $attendee->getActorType() !== Attendee::ACTOR_GUESTS
+				&& $attendee->getActorType() !== Attendee::ACTOR_EMAILS
+				&& $attendee->getActorType() !== Attendee::ACTOR_FEDERATED_USERS) {
 				continue;
 			}
 
@@ -334,6 +339,8 @@ class BackendNotifier {
 				'participantType' => $attendee->getParticipantType(),
 				'participantPermissions' => Attendee::PERMISSIONS_CUSTOM,
 				'displayName' => $attendee->getDisplayName(),
+				'actorType' => $attendee->getActorType(),
+				'actorId' => $attendee->getActorId(),
 			];
 			if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
 				$data['userId'] = $attendee->getActorId();
@@ -413,7 +420,9 @@ class BackendNotifier {
 
 				$attendee = $participant->getAttendee();
 				if ($attendee->getActorType() !== Attendee::ACTOR_USERS
-					&& $attendee->getActorType() !== Attendee::ACTOR_GUESTS) {
+					&& $attendee->getActorType() !== Attendee::ACTOR_GUESTS
+					&& $attendee->getActorType() !== Attendee::ACTOR_EMAILS
+					&& $attendee->getActorType() !== Attendee::ACTOR_FEDERATED_USERS) {
 					continue;
 				}
 
@@ -424,6 +433,8 @@ class BackendNotifier {
 					'nextcloudSessionId' => $session->getSessionId(),
 					'participantType' => $attendee->getParticipantType(),
 					'participantPermissions' => $participant->getPermissions(),
+					'actorType' => $attendee->getActorType(),
+					'actorId' => $attendee->getActorId(),
 				];
 				if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
 					$data['userId'] = $attendee->getActorId();
@@ -460,6 +471,48 @@ class BackendNotifier {
 		]);
 	}
 
+	/**
+	 * Send dial-out requests to the HPB
+	 *
+	 * @param string|bool $callerNumber Send the call anonymous when false, default number when true otherwise the string
+	 * @throws \Exception
+	 */
+	public function dialOutToAttendee(Room $room, Attendee $attendee, string|bool $callerNumber): ?string {
+		$start = microtime(true);
+		$dialoutData = [
+			'type' => 'dialout',
+			'dialout' => [
+				'number' => $attendee->getPhoneNumber(),
+				'options' => [
+					'attendeeId' => $attendee->getId(),
+					'actorType' => $attendee->getActorType(),
+					'actorId' => $attendee->getActorId(),
+				]
+			],
+		];
+		if ($callerNumber === false) {
+			$dialoutData['dialout']['options']['anonymous'] = true;
+		} elseif (is_string($callerNumber)) {
+			$dialoutData['dialout']['options']['caller'] = $callerNumber;
+		}
+		$response = $this->backendRequest($room, $dialoutData);
+
+		if ($response === null) {
+			$this->logger->debug('Room dial out response was NULL');
+			return null;
+		}
+
+		$duration = microtime(true) - $start;
+		$this->logger->debug('Room dial out: {token} {number} ({duration})', [
+			'token' => $room->getToken(),
+			'number' => $attendee->getPhoneNumber(),
+			'duration' => sprintf('%.2f', $duration),
+			'app' => 'spreed-hpb',
+		]);
+
+		return (string)$response->getBody();
+	}
+
 	/**
 	 * Send a message to all sessions currently joined in a room. The message
 	 * will be received by "processRoomMessageEvent" in "signaling.js".
