@@ -15,6 +15,7 @@ use OCA\Talk\Vendor\Psr\SimpleCache\CacheInterface;
 use Throwable;
 
 use function array_unique;
+use function array_values;
 use function is_callable;
 
 /** @api */
@@ -36,9 +37,6 @@ final class MapperBuilder
      * using the given source. These arguments can then be used to decide which
      * implementation should be used.
      *
-     * The callback *must* be pure, its output must be deterministic.
-     * @see https://en.wikipedia.org/wiki/Pure_function
-     *
      * Example:
      *
      * ```php
@@ -57,7 +55,6 @@ final class MapperBuilder
      * ```
      *
      * @param interface-string|class-string $name
-     * @psalm-param pure-callable $callback
      */
     public function infer(string $name, callable $callback): self
     {
@@ -86,9 +83,6 @@ final class MapperBuilder
      * needs to be handled as well, the name of the class must be given to this
      * method.
      *
-     * A constructor *must* be pure, its output must be deterministic.
-     * @see https://en.wikipedia.org/wiki/Pure_function
-     *
      * ```php
      * final class SomeClass
      * {
@@ -200,7 +194,6 @@ final class MapperBuilder
      *     ]);
      * ```
      *
-     * @psalm-param pure-callable|class-string ...$constructors
      * @param callable|class-string ...$constructors
      */
     public function registerConstructor(callable|string ...$constructors): self
@@ -238,7 +231,7 @@ final class MapperBuilder
     public function supportDateFormats(string $format, string ...$formats): self
     {
         $clone = clone $this;
-        $clone->settings->supportedDateFormats = array_unique([$format, ...$formats]);
+        $clone->settings->supportedDateFormats = array_values(array_unique([$format, ...$formats]));
 
         return $clone;
     }
@@ -298,7 +291,6 @@ final class MapperBuilder
 
     /**
      * @template T
-     * @psalm-param pure-callable(T): T $callback
      * @param callable(T): T $callback
      */
     public function alter(callable $callback): self
@@ -418,9 +410,6 @@ final class MapperBuilder
      * part of a query should never be allowed. Therefore, only an exhaustive
      * list of carefully chosen exceptions should be filtered.
      *
-     * The filter callback *must* be pure, its output must be deterministic.
-     * @see https://en.wikipedia.org/wiki/Pure_function
-     *
      * ```php
      * final class SomeClass
      * {
@@ -446,7 +435,6 @@ final class MapperBuilder
      *     ]);
      * ```
      *
-     * @psalm-param pure-callable(Throwable): ErrorMessage $filter
      * @param callable(Throwable): ErrorMessage $filter
      */
     public function filterExceptions(callable $filter): self
@@ -514,7 +502,6 @@ final class MapperBuilder
      *     ->normalize('Hello world'); // HELLO WORLD?!
      * ```
      *
-     * @psalm-param pure-callable|class-string $transformer
      * @param callable|class-string $transformer
      */
     public function registerTransformer(callable|string $transformer, int $priority = 0): self
